# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.6.4
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing_extensions import Annotated
from authentik_client.models.open_id_connect_configuration import OpenIDConnectConfiguration
from authentik_client.models.proxy_mode import ProxyMode
from typing import Optional, Set
from typing_extensions import Self

class ProxyOutpostConfig(BaseModel):
    """
    Proxy provider serializer for outposts
    """ # noqa: E501
    pk: StrictInt
    name: StrictStr
    internal_host: Optional[StrictStr] = None
    external_host: StrictStr
    internal_host_ssl_validation: Optional[StrictBool] = Field(default=None, description="Validate SSL Certificates of upstream servers")
    client_id: Optional[Annotated[str, Field(strict=True, max_length=255)]] = None
    client_secret: Optional[Annotated[str, Field(strict=True, max_length=255)]] = None
    oidc_configuration: OpenIDConnectConfiguration
    cookie_secret: Optional[StrictStr] = None
    certificate: Optional[StrictStr] = None
    skip_path_regex: Optional[StrictStr] = Field(default=None, description="Regular expressions for which authentication is not required. Each new line is interpreted as a new Regular Expression.")
    basic_auth_enabled: Optional[StrictBool] = Field(default=None, description="Set a custom HTTP-Basic Authentication header based on values from authentik.")
    basic_auth_password_attribute: Optional[StrictStr] = Field(default=None, description="User/Group Attribute used for the password part of the HTTP-Basic Header.")
    basic_auth_user_attribute: Optional[StrictStr] = Field(default=None, description="User/Group Attribute used for the user part of the HTTP-Basic Header. If not set, the user's Email address is used.")
    mode: Optional[ProxyMode] = Field(default=None, description="Enable support for forwardAuth in traefik and nginx auth_request. Exclusive with internal_host.")
    cookie_domain: Optional[StrictStr] = None
    access_token_validity: Optional[Union[StrictFloat, StrictInt]] = Field(description="Get token validity as second count")
    intercept_header_auth: Optional[StrictBool] = Field(default=None, description="When enabled, this provider will intercept the authorization header and authenticate requests based on its value.")
    scopes_to_request: List[StrictStr] = Field(description="Get all the scope names the outpost should request, including custom-defined ones")
    assigned_application_slug: StrictStr = Field(description="Internal application name, used in URLs.")
    assigned_application_name: StrictStr = Field(description="Application's display Name.")
    __properties: ClassVar[List[str]] = ["pk", "name", "internal_host", "external_host", "internal_host_ssl_validation", "client_id", "client_secret", "oidc_configuration", "cookie_secret", "certificate", "skip_path_regex", "basic_auth_enabled", "basic_auth_password_attribute", "basic_auth_user_attribute", "mode", "cookie_domain", "access_token_validity", "intercept_header_auth", "scopes_to_request", "assigned_application_slug", "assigned_application_name"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ProxyOutpostConfig from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        """
        excluded_fields: Set[str] = set([
            "pk",
            "oidc_configuration",
            "access_token_validity",
            "scopes_to_request",
            "assigned_application_slug",
            "assigned_application_name",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of oidc_configuration
        if self.oidc_configuration:
            _dict['oidc_configuration'] = self.oidc_configuration.to_dict()
        # set to None if certificate (nullable) is None
        # and model_fields_set contains the field
        if self.certificate is None and "certificate" in self.model_fields_set:
            _dict['certificate'] = None

        # set to None if access_token_validity (nullable) is None
        # and model_fields_set contains the field
        if self.access_token_validity is None and "access_token_validity" in self.model_fields_set:
            _dict['access_token_validity'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ProxyOutpostConfig from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "pk": obj.get("pk"),
            "name": obj.get("name"),
            "internal_host": obj.get("internal_host"),
            "external_host": obj.get("external_host"),
            "internal_host_ssl_validation": obj.get("internal_host_ssl_validation"),
            "client_id": obj.get("client_id"),
            "client_secret": obj.get("client_secret"),
            "oidc_configuration": OpenIDConnectConfiguration.from_dict(obj["oidc_configuration"]) if obj.get("oidc_configuration") is not None else None,
            "cookie_secret": obj.get("cookie_secret"),
            "certificate": obj.get("certificate"),
            "skip_path_regex": obj.get("skip_path_regex"),
            "basic_auth_enabled": obj.get("basic_auth_enabled"),
            "basic_auth_password_attribute": obj.get("basic_auth_password_attribute"),
            "basic_auth_user_attribute": obj.get("basic_auth_user_attribute"),
            "mode": obj.get("mode"),
            "cookie_domain": obj.get("cookie_domain"),
            "access_token_validity": obj.get("access_token_validity"),
            "intercept_header_auth": obj.get("intercept_header_auth"),
            "scopes_to_request": obj.get("scopes_to_request"),
            "assigned_application_slug": obj.get("assigned_application_slug"),
            "assigned_application_name": obj.get("assigned_application_name")
        })
        return _obj





# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.6.4
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.models.role_assigned_object_permission import RoleAssignedObjectPermission

class TestRoleAssignedObjectPermission(unittest.TestCase):
    """RoleAssignedObjectPermission unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RoleAssignedObjectPermission:
        """Test RoleAssignedObjectPermission
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `RoleAssignedObjectPermission`
        """
        model = RoleAssignedObjectPermission()
        if include_optional:
            return RoleAssignedObjectPermission(
                role_pk = '',
                name = '',
                permissions = [
                    authentik_client.models.role_object_permission.RoleObjectPermission(
                        id = 56, 
                        codename = '', 
                        model = '', 
                        app_label = '', 
                        object_pk = '', 
                        name = '', )
                    ]
            )
        else:
            return RoleAssignedObjectPermission(
                role_pk = '',
                name = '',
                permissions = [
                    authentik_client.models.role_object_permission.RoleObjectPermission(
                        id = 56, 
                        codename = '', 
                        model = '', 
                        app_label = '', 
                        object_pk = '', 
                        name = '', )
                    ],
        )
        """

    def testRoleAssignedObjectPermission(self):
        """Test RoleAssignedObjectPermission"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.6.4
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class CapabilitiesEnum(str, Enum):
    """
    CapabilitiesEnum
    """

    """
    allowed enum values
    """
    CAN_SAVE_MEDIA = 'can_save_media'
    CAN_GEO_IP = 'can_geo_ip'
    CAN_ASN = 'can_asn'
    CAN_IMPERSONATE = 'can_impersonate'
    CAN_DEBUG = 'can_debug'
    IS_ENTERPRISE = 'is_enterprise'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of CapabilitiesEnum from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.6.4
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from authentik_client.models.delivery_method_enum import DeliveryMethodEnum
from authentik_client.models.events_requested_enum import EventsRequestedEnum
from authentik_client.models.ssf_provider import SSFProvider
from typing import Optional, Set
from typing_extensions import Self

class SSFStream(BaseModel):
    """
    SSFStream Serializer
    """ # noqa: E501
    pk: StrictStr
    provider: StrictInt
    provider_obj: SSFProvider
    delivery_method: DeliveryMethodEnum
    endpoint_url: Optional[StrictStr] = None
    events_requested: Optional[List[EventsRequestedEnum]] = None
    format: StrictStr
    aud: Optional[List[StrictStr]] = None
    iss: StrictStr
    __properties: ClassVar[List[str]] = ["pk", "provider", "provider_obj", "delivery_method", "endpoint_url", "events_requested", "format", "aud", "iss"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of SSFStream from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        """
        excluded_fields: Set[str] = set([
            "pk",
            "provider_obj",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of provider_obj
        if self.provider_obj:
            _dict['provider_obj'] = self.provider_obj.to_dict()
        # set to None if endpoint_url (nullable) is None
        # and model_fields_set contains the field
        if self.endpoint_url is None and "endpoint_url" in self.model_fields_set:
            _dict['endpoint_url'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of SSFStream from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "pk": obj.get("pk"),
            "provider": obj.get("provider"),
            "provider_obj": SSFProvider.from_dict(obj["provider_obj"]) if obj.get("provider_obj") is not None else None,
            "delivery_method": obj.get("delivery_method"),
            "endpoint_url": obj.get("endpoint_url"),
            "events_requested": obj.get("events_requested"),
            "format": obj.get("format"),
            "aud": obj.get("aud"),
            "iss": obj.get("iss")
        })
        return _obj





# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.6.4
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.models.google_workspace_provider_mapping import GoogleWorkspaceProviderMapping

class TestGoogleWorkspaceProviderMapping(unittest.TestCase):
    """GoogleWorkspaceProviderMapping unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> GoogleWorkspaceProviderMapping:
        """Test GoogleWorkspaceProviderMapping
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `GoogleWorkspaceProviderMapping`
        """
        model = GoogleWorkspaceProviderMapping()
        if include_optional:
            return GoogleWorkspaceProviderMapping(
                pk = '',
                managed = '',
                name = '',
                expression = '',
                component = '',
                verbose_name = '',
                verbose_name_plural = '',
                meta_model_name = ''
            )
        else:
            return GoogleWorkspaceProviderMapping(
                pk = '',
                name = '',
                expression = '',
                component = '',
                verbose_name = '',
                verbose_name_plural = '',
                meta_model_name = '',
        )
        """

    def testGoogleWorkspaceProviderMapping(self):
        """Test GoogleWorkspaceProviderMapping"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.6.4
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.models.ldap_outpost_config import LDAPOutpostConfig

class TestLDAPOutpostConfig(unittest.TestCase):
    """LDAPOutpostConfig unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> LDAPOutpostConfig:
        """Test LDAPOutpostConfig
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `LDAPOutpostConfig`
        """
        model = LDAPOutpostConfig()
        if include_optional:
            return LDAPOutpostConfig(
                pk = 56,
                name = '',
                base_dn = '',
                bind_flow_slug = '',
                unbind_flow_slug = '',
                application_slug = '',
                certificate = '',
                tls_server_name = '',
                uid_start_number = -2147483648,
                gid_start_number = -2147483648,
                search_mode = 'direct',
                bind_mode = 'direct',
                mfa_support = True
            )
        else:
            return LDAPOutpostConfig(
                pk = 56,
                name = '',
                bind_flow_slug = '',
                unbind_flow_slug = '',
                application_slug = '',
        )
        """

    def testLDAPOutpostConfig(self):
        """Test LDAPOutpostConfig"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.6.4
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class CountryCodeEnum(str, Enum):
    """
    CountryCodeEnum
    """

    """
    allowed enum values
    """
    AF = 'AF'
    AX = 'AX'
    AL = 'AL'
    DZ = 'DZ'
    AS = 'AS'
    AD = 'AD'
    AO = 'AO'
    AI = 'AI'
    AQ = 'AQ'
    AG = 'AG'
    AR = 'AR'
    AM = 'AM'
    AW = 'AW'
    AU = 'AU'
    AT = 'AT'
    AZ = 'AZ'
    BS = 'BS'
    BH = 'BH'
    BD = 'BD'
    BB = 'BB'
    BY = 'BY'
    BE = 'BE'
    BZ = 'BZ'
    BJ = 'BJ'
    BM = 'BM'
    BT = 'BT'
    BO = 'BO'
    BQ = 'BQ'
    BA = 'BA'
    BW = 'BW'
    BV = 'BV'
    BR = 'BR'
    IO = 'IO'
    BN = 'BN'
    BG = 'BG'
    BF = 'BF'
    BI = 'BI'
    CV = 'CV'
    KH = 'KH'
    CM = 'CM'
    CA = 'CA'
    KY = 'KY'
    CF = 'CF'
    TD = 'TD'
    CL = 'CL'
    CN = 'CN'
    CX = 'CX'
    CC = 'CC'
    CO = 'CO'
    KM = 'KM'
    CG = 'CG'
    CD = 'CD'
    CK = 'CK'
    CR = 'CR'
    CI = 'CI'
    HR = 'HR'
    CU = 'CU'
    CW = 'CW'
    CY = 'CY'
    CZ = 'CZ'
    DK = 'DK'
    DJ = 'DJ'
    DM = 'DM'
    DO = 'DO'
    EC = 'EC'
    EG = 'EG'
    SV = 'SV'
    GQ = 'GQ'
    ER = 'ER'
    EE = 'EE'
    SZ = 'SZ'
    ET = 'ET'
    FK = 'FK'
    FO = 'FO'
    FJ = 'FJ'
    FI = 'FI'
    FR = 'FR'
    GF = 'GF'
    PF = 'PF'
    TF = 'TF'
    GA = 'GA'
    GM = 'GM'
    GE = 'GE'
    DE = 'DE'
    GH = 'GH'
    GI = 'GI'
    GR = 'GR'
    GL = 'GL'
    GD = 'GD'
    GP = 'GP'
    GU = 'GU'
    GT = 'GT'
    GG = 'GG'
    GN = 'GN'
    GW = 'GW'
    GY = 'GY'
    HT = 'HT'
    HM = 'HM'
    VA = 'VA'
    HN = 'HN'
    HK = 'HK'
    HU = 'HU'
    IS = 'IS'
    IN = 'IN'
    ID = 'ID'
    IR = 'IR'
    IQ = 'IQ'
    IE = 'IE'
    IM = 'IM'
    IL = 'IL'
    IT = 'IT'
    JM = 'JM'
    JP = 'JP'
    JE = 'JE'
    JO = 'JO'
    KZ = 'KZ'
    KE = 'KE'
    KI = 'KI'
    KW = 'KW'
    KG = 'KG'
    LA = 'LA'
    LV = 'LV'
    LB = 'LB'
    LS = 'LS'
    LR = 'LR'
    LY = 'LY'
    LI = 'LI'
    LT = 'LT'
    LU = 'LU'
    MO = 'MO'
    MG = 'MG'
    MW = 'MW'
    MY = 'MY'
    MV = 'MV'
    ML = 'ML'
    MT = 'MT'
    MH = 'MH'
    MQ = 'MQ'
    MR = 'MR'
    MU = 'MU'
    YT = 'YT'
    MX = 'MX'
    FM = 'FM'
    MD = 'MD'
    MC = 'MC'
    MN = 'MN'
    ME = 'ME'
    MS = 'MS'
    MA = 'MA'
    MZ = 'MZ'
    MM = 'MM'
    NA = 'NA'
    NR = 'NR'
    NP = 'NP'
    NL = 'NL'
    NC = 'NC'
    NZ = 'NZ'
    NI = 'NI'
    NE = 'NE'
    NG = 'NG'
    NU = 'NU'
    NF = 'NF'
    KP = 'KP'
    MK = 'MK'
    MP = 'MP'
    NO = 'NO'
    OM = 'OM'
    PK = 'PK'
    PW = 'PW'
    PS = 'PS'
    PA = 'PA'
    PG = 'PG'
    PY = 'PY'
    PE = 'PE'
    PH = 'PH'
    PN = 'PN'
    PL = 'PL'
    PT = 'PT'
    PR = 'PR'
    QA = 'QA'
    RE = 'RE'
    RO = 'RO'
    RU = 'RU'
    RW = 'RW'
    BL = 'BL'
    SH = 'SH'
    KN = 'KN'
    LC = 'LC'
    MF = 'MF'
    PM = 'PM'
    VC = 'VC'
    WS = 'WS'
    SM = 'SM'
    ST = 'ST'
    SA = 'SA'
    SN = 'SN'
    RS = 'RS'
    SC = 'SC'
    SL = 'SL'
    SG = 'SG'
    SX = 'SX'
    SK = 'SK'
    SI = 'SI'
    SB = 'SB'
    SO = 'SO'
    ZA = 'ZA'
    GS = 'GS'
    KR = 'KR'
    SS = 'SS'
    ES = 'ES'
    LK = 'LK'
    SD = 'SD'
    SR = 'SR'
    SJ = 'SJ'
    SE = 'SE'
    CH = 'CH'
    SY = 'SY'
    TW = 'TW'
    TJ = 'TJ'
    TZ = 'TZ'
    TH = 'TH'
    TL = 'TL'
    TG = 'TG'
    TK = 'TK'
    TO = 'TO'
    TT = 'TT'
    TN = 'TN'
    TR = 'TR'
    TM = 'TM'
    TC = 'TC'
    TV = 'TV'
    UG = 'UG'
    UA = 'UA'
    AE = 'AE'
    GB = 'GB'
    UM = 'UM'
    US = 'US'
    UY = 'UY'
    UZ = 'UZ'
    VU = 'VU'
    VE = 'VE'
    VN = 'VN'
    VG = 'VG'
    VI = 'VI'
    WF = 'WF'
    EH = 'EH'
    YE = 'YE'
    ZM = 'ZM'
    ZW = 'ZW'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of CountryCodeEnum from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.6.4
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class EventActions(str, Enum):
    """
    EventActions
    """

    """
    allowed enum values
    """
    LOGIN = 'login'
    LOGIN_FAILED = 'login_failed'
    LOGOUT = 'logout'
    USER_WRITE = 'user_write'
    SUSPICIOUS_REQUEST = 'suspicious_request'
    PASSWORD_SET = 'password_set'
    SECRET_VIEW = 'secret_view'
    SECRET_ROTATE = 'secret_rotate'
    INVITATION_USED = 'invitation_used'
    AUTHORIZE_APPLICATION = 'authorize_application'
    SOURCE_LINKED = 'source_linked'
    IMPERSONATION_STARTED = 'impersonation_started'
    IMPERSONATION_ENDED = 'impersonation_ended'
    FLOW_EXECUTION = 'flow_execution'
    POLICY_EXECUTION = 'policy_execution'
    POLICY_EXCEPTION = 'policy_exception'
    PROPERTY_MAPPING_EXCEPTION = 'property_mapping_exception'
    SYSTEM_TASK_EXECUTION = 'system_task_execution'
    SYSTEM_TASK_EXCEPTION = 'system_task_exception'
    SYSTEM_EXCEPTION = 'system_exception'
    CONFIGURATION_ERROR = 'configuration_error'
    MODEL_CREATED = 'model_created'
    MODEL_UPDATED = 'model_updated'
    MODEL_DELETED = 'model_deleted'
    EMAIL_SENT = 'email_sent'
    UPDATE_AVAILABLE = 'update_available'
    CUSTOM = 'custom_'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of EventActions from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.6.4
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.models.model_request import ModelRequest

class TestModelRequest(unittest.TestCase):
    """ModelRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ModelRequest:
        """Test ModelRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ModelRequest`
        """
        model = ModelRequest()
        if include_optional:
            return ModelRequest(
                name = '0',
                property_mappings = [
                    ''
                    ],
                property_mappings_group = [
                    ''
                    ],
                delegated_subject = '0',
                credentials = {
                    'key' : None
                    },
                scopes = '0',
                exclude_users_service_account = True,
                filter_group = '',
                user_delete_action = 'do_nothing',
                group_delete_action = 'do_nothing',
                default_group_email_domain = '0',
                dry_run = True,
                authentication_flow = '',
                authorization_flow = '',
                invalidation_flow = '',
                base_dn = '0',
                certificate = '',
                tls_server_name = '',
                uid_start_number = -2147483648,
                gid_start_number = -2147483648,
                search_mode = 'direct',
                bind_mode = 'direct',
                mfa_support = True,
                client_id = '0',
                client_secret = '',
                tenant_id = '0',
                client_type = 'confidential',
                access_code_validity = '0',
                access_token_validity = '0',
                refresh_token_validity = '0',
                include_claims_in_id_token = True,
                signing_key = '',
                encryption_key = '',
                redirect_uris = [
                    authentik_client.models.redirect_uri_request.RedirectURIRequest(
                        matching_mode = 'strict', 
                        url = '0', )
                    ],
                sub_mode = 'hashed_user_id',
                issuer_mode = 'global',
                jwt_federation_sources = [
                    ''
                    ],
                jwt_federation_providers = [
                    56
                    ],
                internal_host = '',
                external_host = '0',
                internal_host_ssl_validation = True,
                skip_path_regex = '',
                basic_auth_enabled = True,
                basic_auth_password_attribute = '',
                basic_auth_user_attribute = '',
                mode = 'proxy',
                intercept_header_auth = True,
                cookie_domain = '',
                settings = {
                    'key' : None
                    },
                connection_expiry = '0',
                delete_token_on_disconnect = True,
                client_networks = '0',
                shared_secret = '0',
                acs_url = '0',
                audience = '',
                issuer = '0',
                assertion_valid_not_before = '0',
                assertion_valid_not_on_or_after = '0',
                session_valid_not_on_or_after = '0',
                name_id_mapping = '',
                authn_context_class_ref_mapping = '',
                digest_algorithm = 'http://www.w3.org/2000/09/xmldsig#sha1',
                signature_algorithm = 'http://www.w3.org/2000/09/xmldsig#rsa-sha1',
                signing_kp = '',
                verification_kp = '',
                encryption_kp = '',
                sign_assertion = True,
                sign_response = True,
                sp_binding = 'redirect',
                default_relay_state = '',
                url = '0',
                verify_certificates = True,
                token = '0',
                compatibility_mode = 'default',
                oidc_auth_providers = [
                    56
                    ],
                event_retention = '0'
            )
        else:
            return ModelRequest(
                name = '0',
                delegated_subject = '0',
                credentials = {
                    'key' : None
                    },
                default_group_email_domain = '0',
                authorization_flow = '',
                invalidation_flow = '',
                client_id = '0',
                client_secret = '',
                tenant_id = '0',
                signing_key = '',
                redirect_uris = [
                    authentik_client.models.redirect_uri_request.RedirectURIRequest(
                        matching_mode = 'strict', 
                        url = '0', )
                    ],
                external_host = '0',
                acs_url = '0',
                url = '0',
                token = '0',
        )
        """

    def testModelRequest(self):
        """Test ModelRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.6.4
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.models.paginated_prompt_list import PaginatedPromptList

class TestPaginatedPromptList(unittest.TestCase):
    """PaginatedPromptList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PaginatedPromptList:
        """Test PaginatedPromptList
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PaginatedPromptList`
        """
        model = PaginatedPromptList()
        if include_optional:
            return PaginatedPromptList(
                pagination = authentik_client.models.pagination.Pagination(
                    next = 1.337, 
                    previous = 1.337, 
                    count = 1.337, 
                    current = 1.337, 
                    total_pages = 1.337, 
                    start_index = 1.337, 
                    end_index = 1.337, ),
                results = [
                    authentik_client.models.prompt.Prompt(
                        pk = '', 
                        name = '', 
                        field_key = '', 
                        label = '', 
                        type = 'text', 
                        required = True, 
                        placeholder = '', 
                        initial_value = '', 
                        order = -2147483648, 
                        promptstage_set = [
                            authentik_client.models.stage.Stage(
                                pk = '', 
                                name = '', 
                                component = '', 
                                verbose_name = '', 
                                verbose_name_plural = '', 
                                meta_model_name = '', 
                                flow_set = [
                                    authentik_client.models.flow_set.FlowSet(
                                        pk = '', 
                                        policybindingmodel_ptr_id = '', 
                                        name = '', 
                                        slug = 'z', 
                                        title = '', 
                                        designation = null, 
                                        background = '', 
                                        policy_engine_mode = 'all', 
                                        compatibility_mode = True, 
                                        export_url = '', 
                                        layout = 'stacked', 
                                        denied_action = null, )
                                    ], )
                            ], 
                        sub_text = '', 
                        placeholder_expression = True, 
                        initial_value_expression = True, )
                    ],
                autocomplete = {
                    'key' : null
                    }
            )
        else:
            return PaginatedPromptList(
                pagination = authentik_client.models.pagination.Pagination(
                    next = 1.337, 
                    previous = 1.337, 
                    count = 1.337, 
                    current = 1.337, 
                    total_pages = 1.337, 
                    start_index = 1.337, 
                    end_index = 1.337, ),
                results = [
                    authentik_client.models.prompt.Prompt(
                        pk = '', 
                        name = '', 
                        field_key = '', 
                        label = '', 
                        type = 'text', 
                        required = True, 
                        placeholder = '', 
                        initial_value = '', 
                        order = -2147483648, 
                        promptstage_set = [
                            authentik_client.models.stage.Stage(
                                pk = '', 
                                name = '', 
                                component = '', 
                                verbose_name = '', 
                                verbose_name_plural = '', 
                                meta_model_name = '', 
                                flow_set = [
                                    authentik_client.models.flow_set.FlowSet(
                                        pk = '', 
                                        policybindingmodel_ptr_id = '', 
                                        name = '', 
                                        slug = 'z', 
                                        title = '', 
                                        designation = null, 
                                        background = '', 
                                        policy_engine_mode = 'all', 
                                        compatibility_mode = True, 
                                        export_url = '', 
                                        layout = 'stacked', 
                                        denied_action = null, )
                                    ], )
                            ], 
                        sub_text = '', 
                        placeholder_expression = True, 
                        initial_value_expression = True, )
                    ],
                autocomplete = {
                    'key' : null
                    },
        )
        """

    def testPaginatedPromptList(self):
        """Test PaginatedPromptList"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.6.4
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.api.outposts_api import OutpostsApi


class TestOutpostsApi(unittest.TestCase):
    """OutpostsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = OutpostsApi()

    def tearDown(self) -> None:
        pass

    def test_outposts_instances_create(self) -> None:
        """Test case for outposts_instances_create

        """
        pass

    def test_outposts_instances_default_settings_retrieve(self) -> None:
        """Test case for outposts_instances_default_settings_retrieve

        """
        pass

    def test_outposts_instances_destroy(self) -> None:
        """Test case for outposts_instances_destroy

        """
        pass

    def test_outposts_instances_health_list(self) -> None:
        """Test case for outposts_instances_health_list

        """
        pass

    def test_outposts_instances_list(self) -> None:
        """Test case for outposts_instances_list

        """
        pass

    def test_outposts_instances_partial_update(self) -> None:
        """Test case for outposts_instances_partial_update

        """
        pass

    def test_outposts_instances_retrieve(self) -> None:
        """Test case for outposts_instances_retrieve

        """
        pass

    def test_outposts_instances_update(self) -> None:
        """Test case for outposts_instances_update

        """
        pass

    def test_outposts_instances_used_by_list(self) -> None:
        """Test case for outposts_instances_used_by_list

        """
        pass

    def test_outposts_ldap_access_check(self) -> None:
        """Test case for outposts_ldap_access_check

        """
        pass

    def test_outposts_ldap_list(self) -> None:
        """Test case for outposts_ldap_list

        """
        pass

    def test_outposts_proxy_list(self) -> None:
        """Test case for outposts_proxy_list

        """
        pass

    def test_outposts_radius_access_check(self) -> None:
        """Test case for outposts_radius_access_check

        """
        pass

    def test_outposts_radius_list(self) -> None:
        """Test case for outposts_radius_list

        """
        pass

    def test_outposts_service_connections_all_destroy(self) -> None:
        """Test case for outposts_service_connections_all_destroy

        """
        pass

    def test_outposts_service_connections_all_list(self) -> None:
        """Test case for outposts_service_connections_all_list

        """
        pass

    def test_outposts_service_connections_all_retrieve(self) -> None:
        """Test case for outposts_service_connections_all_retrieve

        """
        pass

    def test_outposts_service_connections_all_state_retrieve(self) -> None:
        """Test case for outposts_service_connections_all_state_retrieve

        """
        pass

    def test_outposts_service_connections_all_types_list(self) -> None:
        """Test case for outposts_service_connections_all_types_list

        """
        pass

    def test_outposts_service_connections_all_used_by_list(self) -> None:
        """Test case for outposts_service_connections_all_used_by_list

        """
        pass

    def test_outposts_service_connections_docker_create(self) -> None:
        """Test case for outposts_service_connections_docker_create

        """
        pass

    def test_outposts_service_connections_docker_destroy(self) -> None:
        """Test case for outposts_service_connections_docker_destroy

        """
        pass

    def test_outposts_service_connections_docker_list(self) -> None:
        """Test case for outposts_service_connections_docker_list

        """
        pass

    def test_outposts_service_connections_docker_partial_update(self) -> None:
        """Test case for outposts_service_connections_docker_partial_update

        """
        pass

    def test_outposts_service_connections_docker_retrieve(self) -> None:
        """Test case for outposts_service_connections_docker_retrieve

        """
        pass

    def test_outposts_service_connections_docker_update(self) -> None:
        """Test case for outposts_service_connections_docker_update

        """
        pass

    def test_outposts_service_connections_docker_used_by_list(self) -> None:
        """Test case for outposts_service_connections_docker_used_by_list

        """
        pass

    def test_outposts_service_connections_kubernetes_create(self) -> None:
        """Test case for outposts_service_connections_kubernetes_create

        """
        pass

    def test_outposts_service_connections_kubernetes_destroy(self) -> None:
        """Test case for outposts_service_connections_kubernetes_destroy

        """
        pass

    def test_outposts_service_connections_kubernetes_list(self) -> None:
        """Test case for outposts_service_connections_kubernetes_list

        """
        pass

    def test_outposts_service_connections_kubernetes_partial_update(self) -> None:
        """Test case for outposts_service_connections_kubernetes_partial_update

        """
        pass

    def test_outposts_service_connections_kubernetes_retrieve(self) -> None:
        """Test case for outposts_service_connections_kubernetes_retrieve

        """
        pass

    def test_outposts_service_connections_kubernetes_update(self) -> None:
        """Test case for outposts_service_connections_kubernetes_update

        """
        pass

    def test_outposts_service_connections_kubernetes_used_by_list(self) -> None:
        """Test case for outposts_service_connections_kubernetes_used_by_list

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.6.4
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.models.authenticator_web_authn_stage import AuthenticatorWebAuthnStage

class TestAuthenticatorWebAuthnStage(unittest.TestCase):
    """AuthenticatorWebAuthnStage unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AuthenticatorWebAuthnStage:
        """Test AuthenticatorWebAuthnStage
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AuthenticatorWebAuthnStage`
        """
        model = AuthenticatorWebAuthnStage()
        if include_optional:
            return AuthenticatorWebAuthnStage(
                pk = '',
                name = '',
                component = '',
                verbose_name = '',
                verbose_name_plural = '',
                meta_model_name = '',
                flow_set = [
                    authentik_client.models.flow_set.FlowSet(
                        pk = '', 
                        policybindingmodel_ptr_id = '', 
                        name = '', 
                        slug = 'z', 
                        title = '', 
                        designation = null, 
                        background = '', 
                        policy_engine_mode = 'all', 
                        compatibility_mode = True, 
                        export_url = '', 
                        layout = 'stacked', 
                        denied_action = null, )
                    ],
                configure_flow = '',
                friendly_name = '',
                user_verification = 'required',
                authenticator_attachment = 'platform',
                resident_key_requirement = 'discouraged',
                device_type_restrictions = [
                    ''
                    ],
                device_type_restrictions_obj = [
                    authentik_client.models.web_authn_device_type.WebAuthnDeviceType(
                        aaguid = '', 
                        description = '', )
                    ],
                max_attempts = 0
            )
        else:
            return AuthenticatorWebAuthnStage(
                pk = '',
                name = '',
                component = '',
                verbose_name = '',
                verbose_name_plural = '',
                meta_model_name = '',
                device_type_restrictions_obj = [
                    authentik_client.models.web_authn_device_type.WebAuthnDeviceType(
                        aaguid = '', 
                        description = '', )
                    ],
        )
        """

    def testAuthenticatorWebAuthnStage(self):
        """Test AuthenticatorWebAuthnStage"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.6.4
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List
from authentik_client.models.source import Source
from typing import Optional, Set
from typing_extensions import Self

class GroupPlexSourceConnection(BaseModel):
    """
    Group Source Connection
    """ # noqa: E501
    pk: StrictInt
    group: StrictStr
    source: StrictStr
    source_obj: Source
    identifier: StrictStr
    created: datetime
    last_updated: datetime
    __properties: ClassVar[List[str]] = ["pk", "group", "source", "source_obj", "identifier", "created", "last_updated"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of GroupPlexSourceConnection from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        """
        excluded_fields: Set[str] = set([
            "pk",
            "source_obj",
            "created",
            "last_updated",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of source_obj
        if self.source_obj:
            _dict['source_obj'] = self.source_obj.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of GroupPlexSourceConnection from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "pk": obj.get("pk"),
            "group": obj.get("group"),
            "source": obj.get("source"),
            "source_obj": Source.from_dict(obj["source_obj"]) if obj.get("source_obj") is not None else None,
            "identifier": obj.get("identifier"),
            "created": obj.get("created"),
            "last_updated": obj.get("last_updated")
        })
        return _obj





# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.6.4
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.api.stages_api import StagesApi


class TestStagesApi(unittest.TestCase):
    """StagesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = StagesApi()

    def tearDown(self) -> None:
        pass

    def test_stages_all_destroy(self) -> None:
        """Test case for stages_all_destroy

        """
        pass

    def test_stages_all_list(self) -> None:
        """Test case for stages_all_list

        """
        pass

    def test_stages_all_retrieve(self) -> None:
        """Test case for stages_all_retrieve

        """
        pass

    def test_stages_all_types_list(self) -> None:
        """Test case for stages_all_types_list

        """
        pass

    def test_stages_all_used_by_list(self) -> None:
        """Test case for stages_all_used_by_list

        """
        pass

    def test_stages_all_user_settings_list(self) -> None:
        """Test case for stages_all_user_settings_list

        """
        pass

    def test_stages_authenticator_duo_create(self) -> None:
        """Test case for stages_authenticator_duo_create

        """
        pass

    def test_stages_authenticator_duo_destroy(self) -> None:
        """Test case for stages_authenticator_duo_destroy

        """
        pass

    def test_stages_authenticator_duo_enrollment_status_create(self) -> None:
        """Test case for stages_authenticator_duo_enrollment_status_create

        """
        pass

    def test_stages_authenticator_duo_import_device_manual_create(self) -> None:
        """Test case for stages_authenticator_duo_import_device_manual_create

        """
        pass

    def test_stages_authenticator_duo_import_devices_automatic_create(self) -> None:
        """Test case for stages_authenticator_duo_import_devices_automatic_create

        """
        pass

    def test_stages_authenticator_duo_list(self) -> None:
        """Test case for stages_authenticator_duo_list

        """
        pass

    def test_stages_authenticator_duo_partial_update(self) -> None:
        """Test case for stages_authenticator_duo_partial_update

        """
        pass

    def test_stages_authenticator_duo_retrieve(self) -> None:
        """Test case for stages_authenticator_duo_retrieve

        """
        pass

    def test_stages_authenticator_duo_update(self) -> None:
        """Test case for stages_authenticator_duo_update

        """
        pass

    def test_stages_authenticator_duo_used_by_list(self) -> None:
        """Test case for stages_authenticator_duo_used_by_list

        """
        pass

    def test_stages_authenticator_email_create(self) -> None:
        """Test case for stages_authenticator_email_create

        """
        pass

    def test_stages_authenticator_email_destroy(self) -> None:
        """Test case for stages_authenticator_email_destroy

        """
        pass

    def test_stages_authenticator_email_list(self) -> None:
        """Test case for stages_authenticator_email_list

        """
        pass

    def test_stages_authenticator_email_partial_update(self) -> None:
        """Test case for stages_authenticator_email_partial_update

        """
        pass

    def test_stages_authenticator_email_retrieve(self) -> None:
        """Test case for stages_authenticator_email_retrieve

        """
        pass

    def test_stages_authenticator_email_update(self) -> None:
        """Test case for stages_authenticator_email_update

        """
        pass

    def test_stages_authenticator_email_used_by_list(self) -> None:
        """Test case for stages_authenticator_email_used_by_list

        """
        pass

    def test_stages_authenticator_endpoint_gdtc_create(self) -> None:
        """Test case for stages_authenticator_endpoint_gdtc_create

        """
        pass

    def test_stages_authenticator_endpoint_gdtc_destroy(self) -> None:
        """Test case for stages_authenticator_endpoint_gdtc_destroy

        """
        pass

    def test_stages_authenticator_endpoint_gdtc_list(self) -> None:
        """Test case for stages_authenticator_endpoint_gdtc_list

        """
        pass

    def test_stages_authenticator_endpoint_gdtc_partial_update(self) -> None:
        """Test case for stages_authenticator_endpoint_gdtc_partial_update

        """
        pass

    def test_stages_authenticator_endpoint_gdtc_retrieve(self) -> None:
        """Test case for stages_authenticator_endpoint_gdtc_retrieve

        """
        pass

    def test_stages_authenticator_endpoint_gdtc_update(self) -> None:
        """Test case for stages_authenticator_endpoint_gdtc_update

        """
        pass

    def test_stages_authenticator_endpoint_gdtc_used_by_list(self) -> None:
        """Test case for stages_authenticator_endpoint_gdtc_used_by_list

        """
        pass

    def test_stages_authenticator_sms_create(self) -> None:
        """Test case for stages_authenticator_sms_create

        """
        pass

    def test_stages_authenticator_sms_destroy(self) -> None:
        """Test case for stages_authenticator_sms_destroy

        """
        pass

    def test_stages_authenticator_sms_list(self) -> None:
        """Test case for stages_authenticator_sms_list

        """
        pass

    def test_stages_authenticator_sms_partial_update(self) -> None:
        """Test case for stages_authenticator_sms_partial_update

        """
        pass

    def test_stages_authenticator_sms_retrieve(self) -> None:
        """Test case for stages_authenticator_sms_retrieve

        """
        pass

    def test_stages_authenticator_sms_update(self) -> None:
        """Test case for stages_authenticator_sms_update

        """
        pass

    def test_stages_authenticator_sms_used_by_list(self) -> None:
        """Test case for stages_authenticator_sms_used_by_list

        """
        pass

    def test_stages_authenticator_static_create(self) -> None:
        """Test case for stages_authenticator_static_create

        """
        pass

    def test_stages_authenticator_static_destroy(self) -> None:
        """Test case for stages_authenticator_static_destroy

        """
        pass

    def test_stages_authenticator_static_list(self) -> None:
        """Test case for stages_authenticator_static_list

        """
        pass

    def test_stages_authenticator_static_partial_update(self) -> None:
        """Test case for stages_authenticator_static_partial_update

        """
        pass

    def test_stages_authenticator_static_retrieve(self) -> None:
        """Test case for stages_authenticator_static_retrieve

        """
        pass

    def test_stages_authenticator_static_update(self) -> None:
        """Test case for stages_authenticator_static_update

        """
        pass

    def test_stages_authenticator_static_used_by_list(self) -> None:
        """Test case for stages_authenticator_static_used_by_list

        """
        pass

    def test_stages_authenticator_totp_create(self) -> None:
        """Test case for stages_authenticator_totp_create

        """
        pass

    def test_stages_authenticator_totp_destroy(self) -> None:
        """Test case for stages_authenticator_totp_destroy

        """
        pass

    def test_stages_authenticator_totp_list(self) -> None:
        """Test case for stages_authenticator_totp_list

        """
        pass

    def test_stages_authenticator_totp_partial_update(self) -> None:
        """Test case for stages_authenticator_totp_partial_update

        """
        pass

    def test_stages_authenticator_totp_retrieve(self) -> None:
        """Test case for stages_authenticator_totp_retrieve

        """
        pass

    def test_stages_authenticator_totp_update(self) -> None:
        """Test case for stages_authenticator_totp_update

        """
        pass

    def test_stages_authenticator_totp_used_by_list(self) -> None:
        """Test case for stages_authenticator_totp_used_by_list

        """
        pass

    def test_stages_authenticator_validate_create(self) -> None:
        """Test case for stages_authenticator_validate_create

        """
        pass

    def test_stages_authenticator_validate_destroy(self) -> None:
        """Test case for stages_authenticator_validate_destroy

        """
        pass

    def test_stages_authenticator_validate_list(self) -> None:
        """Test case for stages_authenticator_validate_list

        """
        pass

    def test_stages_authenticator_validate_partial_update(self) -> None:
        """Test case for stages_authenticator_validate_partial_update

        """
        pass

    def test_stages_authenticator_validate_retrieve(self) -> None:
        """Test case for stages_authenticator_validate_retrieve

        """
        pass

    def test_stages_authenticator_validate_update(self) -> None:
        """Test case for stages_authenticator_validate_update

        """
        pass

    def test_stages_authenticator_validate_used_by_list(self) -> None:
        """Test case for stages_authenticator_validate_used_by_list

        """
        pass

    def test_stages_authenticator_webauthn_create(self) -> None:
        """Test case for stages_authenticator_webauthn_create

        """
        pass

    def test_stages_authenticator_webauthn_destroy(self) -> None:
        """Test case for stages_authenticator_webauthn_destroy

        """
        pass

    def test_stages_authenticator_webauthn_device_types_list(self) -> None:
        """Test case for stages_authenticator_webauthn_device_types_list

        """
        pass

    def test_stages_authenticator_webauthn_device_types_retrieve(self) -> None:
        """Test case for stages_authenticator_webauthn_device_types_retrieve

        """
        pass

    def test_stages_authenticator_webauthn_list(self) -> None:
        """Test case for stages_authenticator_webauthn_list

        """
        pass

    def test_stages_authenticator_webauthn_partial_update(self) -> None:
        """Test case for stages_authenticator_webauthn_partial_update

        """
        pass

    def test_stages_authenticator_webauthn_retrieve(self) -> None:
        """Test case for stages_authenticator_webauthn_retrieve

        """
        pass

    def test_stages_authenticator_webauthn_update(self) -> None:
        """Test case for stages_authenticator_webauthn_update

        """
        pass

    def test_stages_authenticator_webauthn_used_by_list(self) -> None:
        """Test case for stages_authenticator_webauthn_used_by_list

        """
        pass

    def test_stages_captcha_create(self) -> None:
        """Test case for stages_captcha_create

        """
        pass

    def test_stages_captcha_destroy(self) -> None:
        """Test case for stages_captcha_destroy

        """
        pass

    def test_stages_captcha_list(self) -> None:
        """Test case for stages_captcha_list

        """
        pass

    def test_stages_captcha_partial_update(self) -> None:
        """Test case for stages_captcha_partial_update

        """
        pass

    def test_stages_captcha_retrieve(self) -> None:
        """Test case for stages_captcha_retrieve

        """
        pass

    def test_stages_captcha_update(self) -> None:
        """Test case for stages_captcha_update

        """
        pass

    def test_stages_captcha_used_by_list(self) -> None:
        """Test case for stages_captcha_used_by_list

        """
        pass

    def test_stages_consent_create(self) -> None:
        """Test case for stages_consent_create

        """
        pass

    def test_stages_consent_destroy(self) -> None:
        """Test case for stages_consent_destroy

        """
        pass

    def test_stages_consent_list(self) -> None:
        """Test case for stages_consent_list

        """
        pass

    def test_stages_consent_partial_update(self) -> None:
        """Test case for stages_consent_partial_update

        """
        pass

    def test_stages_consent_retrieve(self) -> None:
        """Test case for stages_consent_retrieve

        """
        pass

    def test_stages_consent_update(self) -> None:
        """Test case for stages_consent_update

        """
        pass

    def test_stages_consent_used_by_list(self) -> None:
        """Test case for stages_consent_used_by_list

        """
        pass

    def test_stages_deny_create(self) -> None:
        """Test case for stages_deny_create

        """
        pass

    def test_stages_deny_destroy(self) -> None:
        """Test case for stages_deny_destroy

        """
        pass

    def test_stages_deny_list(self) -> None:
        """Test case for stages_deny_list

        """
        pass

    def test_stages_deny_partial_update(self) -> None:
        """Test case for stages_deny_partial_update

        """
        pass

    def test_stages_deny_retrieve(self) -> None:
        """Test case for stages_deny_retrieve

        """
        pass

    def test_stages_deny_update(self) -> None:
        """Test case for stages_deny_update

        """
        pass

    def test_stages_deny_used_by_list(self) -> None:
        """Test case for stages_deny_used_by_list

        """
        pass

    def test_stages_dummy_create(self) -> None:
        """Test case for stages_dummy_create

        """
        pass

    def test_stages_dummy_destroy(self) -> None:
        """Test case for stages_dummy_destroy

        """
        pass

    def test_stages_dummy_list(self) -> None:
        """Test case for stages_dummy_list

        """
        pass

    def test_stages_dummy_partial_update(self) -> None:
        """Test case for stages_dummy_partial_update

        """
        pass

    def test_stages_dummy_retrieve(self) -> None:
        """Test case for stages_dummy_retrieve

        """
        pass

    def test_stages_dummy_update(self) -> None:
        """Test case for stages_dummy_update

        """
        pass

    def test_stages_dummy_used_by_list(self) -> None:
        """Test case for stages_dummy_used_by_list

        """
        pass

    def test_stages_email_create(self) -> None:
        """Test case for stages_email_create

        """
        pass

    def test_stages_email_destroy(self) -> None:
        """Test case for stages_email_destroy

        """
        pass

    def test_stages_email_list(self) -> None:
        """Test case for stages_email_list

        """
        pass

    def test_stages_email_partial_update(self) -> None:
        """Test case for stages_email_partial_update

        """
        pass

    def test_stages_email_retrieve(self) -> None:
        """Test case for stages_email_retrieve

        """
        pass

    def test_stages_email_templates_list(self) -> None:
        """Test case for stages_email_templates_list

        """
        pass

    def test_stages_email_update(self) -> None:
        """Test case for stages_email_update

        """
        pass

    def test_stages_email_used_by_list(self) -> None:
        """Test case for stages_email_used_by_list

        """
        pass

    def test_stages_identification_create(self) -> None:
        """Test case for stages_identification_create

        """
        pass

    def test_stages_identification_destroy(self) -> None:
        """Test case for stages_identification_destroy

        """
        pass

    def test_stages_identification_list(self) -> None:
        """Test case for stages_identification_list

        """
        pass

    def test_stages_identification_partial_update(self) -> None:
        """Test case for stages_identification_partial_update

        """
        pass

    def test_stages_identification_retrieve(self) -> None:
        """Test case for stages_identification_retrieve

        """
        pass

    def test_stages_identification_update(self) -> None:
        """Test case for stages_identification_update

        """
        pass

    def test_stages_identification_used_by_list(self) -> None:
        """Test case for stages_identification_used_by_list

        """
        pass

    def test_stages_invitation_invitations_create(self) -> None:
        """Test case for stages_invitation_invitations_create

        """
        pass

    def test_stages_invitation_invitations_destroy(self) -> None:
        """Test case for stages_invitation_invitations_destroy

        """
        pass

    def test_stages_invitation_invitations_list(self) -> None:
        """Test case for stages_invitation_invitations_list

        """
        pass

    def test_stages_invitation_invitations_partial_update(self) -> None:
        """Test case for stages_invitation_invitations_partial_update

        """
        pass

    def test_stages_invitation_invitations_retrieve(self) -> None:
        """Test case for stages_invitation_invitations_retrieve

        """
        pass

    def test_stages_invitation_invitations_update(self) -> None:
        """Test case for stages_invitation_invitations_update

        """
        pass

    def test_stages_invitation_invitations_used_by_list(self) -> None:
        """Test case for stages_invitation_invitations_used_by_list

        """
        pass

    def test_stages_invitation_stages_create(self) -> None:
        """Test case for stages_invitation_stages_create

        """
        pass

    def test_stages_invitation_stages_destroy(self) -> None:
        """Test case for stages_invitation_stages_destroy

        """
        pass

    def test_stages_invitation_stages_list(self) -> None:
        """Test case for stages_invitation_stages_list

        """
        pass

    def test_stages_invitation_stages_partial_update(self) -> None:
        """Test case for stages_invitation_stages_partial_update

        """
        pass

    def test_stages_invitation_stages_retrieve(self) -> None:
        """Test case for stages_invitation_stages_retrieve

        """
        pass

    def test_stages_invitation_stages_update(self) -> None:
        """Test case for stages_invitation_stages_update

        """
        pass

    def test_stages_invitation_stages_used_by_list(self) -> None:
        """Test case for stages_invitation_stages_used_by_list

        """
        pass

    def test_stages_mtls_create(self) -> None:
        """Test case for stages_mtls_create

        """
        pass

    def test_stages_mtls_destroy(self) -> None:
        """Test case for stages_mtls_destroy

        """
        pass

    def test_stages_mtls_list(self) -> None:
        """Test case for stages_mtls_list

        """
        pass

    def test_stages_mtls_partial_update(self) -> None:
        """Test case for stages_mtls_partial_update

        """
        pass

    def test_stages_mtls_retrieve(self) -> None:
        """Test case for stages_mtls_retrieve

        """
        pass

    def test_stages_mtls_update(self) -> None:
        """Test case for stages_mtls_update

        """
        pass

    def test_stages_mtls_used_by_list(self) -> None:
        """Test case for stages_mtls_used_by_list

        """
        pass

    def test_stages_password_create(self) -> None:
        """Test case for stages_password_create

        """
        pass

    def test_stages_password_destroy(self) -> None:
        """Test case for stages_password_destroy

        """
        pass

    def test_stages_password_list(self) -> None:
        """Test case for stages_password_list

        """
        pass

    def test_stages_password_partial_update(self) -> None:
        """Test case for stages_password_partial_update

        """
        pass

    def test_stages_password_retrieve(self) -> None:
        """Test case for stages_password_retrieve

        """
        pass

    def test_stages_password_update(self) -> None:
        """Test case for stages_password_update

        """
        pass

    def test_stages_password_used_by_list(self) -> None:
        """Test case for stages_password_used_by_list

        """
        pass

    def test_stages_prompt_prompts_create(self) -> None:
        """Test case for stages_prompt_prompts_create

        """
        pass

    def test_stages_prompt_prompts_destroy(self) -> None:
        """Test case for stages_prompt_prompts_destroy

        """
        pass

    def test_stages_prompt_prompts_list(self) -> None:
        """Test case for stages_prompt_prompts_list

        """
        pass

    def test_stages_prompt_prompts_partial_update(self) -> None:
        """Test case for stages_prompt_prompts_partial_update

        """
        pass

    def test_stages_prompt_prompts_preview_create(self) -> None:
        """Test case for stages_prompt_prompts_preview_create

        """
        pass

    def test_stages_prompt_prompts_retrieve(self) -> None:
        """Test case for stages_prompt_prompts_retrieve

        """
        pass

    def test_stages_prompt_prompts_update(self) -> None:
        """Test case for stages_prompt_prompts_update

        """
        pass

    def test_stages_prompt_prompts_used_by_list(self) -> None:
        """Test case for stages_prompt_prompts_used_by_list

        """
        pass

    def test_stages_prompt_stages_create(self) -> None:
        """Test case for stages_prompt_stages_create

        """
        pass

    def test_stages_prompt_stages_destroy(self) -> None:
        """Test case for stages_prompt_stages_destroy

        """
        pass

    def test_stages_prompt_stages_list(self) -> None:
        """Test case for stages_prompt_stages_list

        """
        pass

    def test_stages_prompt_stages_partial_update(self) -> None:
        """Test case for stages_prompt_stages_partial_update

        """
        pass

    def test_stages_prompt_stages_retrieve(self) -> None:
        """Test case for stages_prompt_stages_retrieve

        """
        pass

    def test_stages_prompt_stages_update(self) -> None:
        """Test case for stages_prompt_stages_update

        """
        pass

    def test_stages_prompt_stages_used_by_list(self) -> None:
        """Test case for stages_prompt_stages_used_by_list

        """
        pass

    def test_stages_redirect_create(self) -> None:
        """Test case for stages_redirect_create

        """
        pass

    def test_stages_redirect_destroy(self) -> None:
        """Test case for stages_redirect_destroy

        """
        pass

    def test_stages_redirect_list(self) -> None:
        """Test case for stages_redirect_list

        """
        pass

    def test_stages_redirect_partial_update(self) -> None:
        """Test case for stages_redirect_partial_update

        """
        pass

    def test_stages_redirect_retrieve(self) -> None:
        """Test case for stages_redirect_retrieve

        """
        pass

    def test_stages_redirect_update(self) -> None:
        """Test case for stages_redirect_update

        """
        pass

    def test_stages_redirect_used_by_list(self) -> None:
        """Test case for stages_redirect_used_by_list

        """
        pass

    def test_stages_source_create(self) -> None:
        """Test case for stages_source_create

        """
        pass

    def test_stages_source_destroy(self) -> None:
        """Test case for stages_source_destroy

        """
        pass

    def test_stages_source_list(self) -> None:
        """Test case for stages_source_list

        """
        pass

    def test_stages_source_partial_update(self) -> None:
        """Test case for stages_source_partial_update

        """
        pass

    def test_stages_source_retrieve(self) -> None:
        """Test case for stages_source_retrieve

        """
        pass

    def test_stages_source_update(self) -> None:
        """Test case for stages_source_update

        """
        pass

    def test_stages_source_used_by_list(self) -> None:
        """Test case for stages_source_used_by_list

        """
        pass

    def test_stages_user_delete_create(self) -> None:
        """Test case for stages_user_delete_create

        """
        pass

    def test_stages_user_delete_destroy(self) -> None:
        """Test case for stages_user_delete_destroy

        """
        pass

    def test_stages_user_delete_list(self) -> None:
        """Test case for stages_user_delete_list

        """
        pass

    def test_stages_user_delete_partial_update(self) -> None:
        """Test case for stages_user_delete_partial_update

        """
        pass

    def test_stages_user_delete_retrieve(self) -> None:
        """Test case for stages_user_delete_retrieve

        """
        pass

    def test_stages_user_delete_update(self) -> None:
        """Test case for stages_user_delete_update

        """
        pass

    def test_stages_user_delete_used_by_list(self) -> None:
        """Test case for stages_user_delete_used_by_list

        """
        pass

    def test_stages_user_login_create(self) -> None:
        """Test case for stages_user_login_create

        """
        pass

    def test_stages_user_login_destroy(self) -> None:
        """Test case for stages_user_login_destroy

        """
        pass

    def test_stages_user_login_list(self) -> None:
        """Test case for stages_user_login_list

        """
        pass

    def test_stages_user_login_partial_update(self) -> None:
        """Test case for stages_user_login_partial_update

        """
        pass

    def test_stages_user_login_retrieve(self) -> None:
        """Test case for stages_user_login_retrieve

        """
        pass

    def test_stages_user_login_update(self) -> None:
        """Test case for stages_user_login_update

        """
        pass

    def test_stages_user_login_used_by_list(self) -> None:
        """Test case for stages_user_login_used_by_list

        """
        pass

    def test_stages_user_logout_create(self) -> None:
        """Test case for stages_user_logout_create

        """
        pass

    def test_stages_user_logout_destroy(self) -> None:
        """Test case for stages_user_logout_destroy

        """
        pass

    def test_stages_user_logout_list(self) -> None:
        """Test case for stages_user_logout_list

        """
        pass

    def test_stages_user_logout_partial_update(self) -> None:
        """Test case for stages_user_logout_partial_update

        """
        pass

    def test_stages_user_logout_retrieve(self) -> None:
        """Test case for stages_user_logout_retrieve

        """
        pass

    def test_stages_user_logout_update(self) -> None:
        """Test case for stages_user_logout_update

        """
        pass

    def test_stages_user_logout_used_by_list(self) -> None:
        """Test case for stages_user_logout_used_by_list

        """
        pass

    def test_stages_user_write_create(self) -> None:
        """Test case for stages_user_write_create

        """
        pass

    def test_stages_user_write_destroy(self) -> None:
        """Test case for stages_user_write_destroy

        """
        pass

    def test_stages_user_write_list(self) -> None:
        """Test case for stages_user_write_list

        """
        pass

    def test_stages_user_write_partial_update(self) -> None:
        """Test case for stages_user_write_partial_update

        """
        pass

    def test_stages_user_write_retrieve(self) -> None:
        """Test case for stages_user_write_retrieve

        """
        pass

    def test_stages_user_write_update(self) -> None:
        """Test case for stages_user_write_update

        """
        pass

    def test_stages_user_write_used_by_list(self) -> None:
        """Test case for stages_user_write_used_by_list

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.6.4
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.models.patched_token_request import PatchedTokenRequest

class TestPatchedTokenRequest(unittest.TestCase):
    """PatchedTokenRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PatchedTokenRequest:
        """Test PatchedTokenRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PatchedTokenRequest`
        """
        model = PatchedTokenRequest()
        if include_optional:
            return PatchedTokenRequest(
                managed = '0',
                identifier = 'z0',
                intent = 'verification',
                user = 56,
                description = '',
                expires = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                expiring = True
            )
        else:
            return PatchedTokenRequest(
        )
        """

    def testPatchedTokenRequest(self):
        """Test PatchedTokenRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.6.4
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class DeliveryMethodEnum(str, Enum):
    """
    DeliveryMethodEnum
    """

    """
    allowed enum values
    """
    HTTPS_COLON_SLASH_SLASH_SCHEMAS_DOT_OPENID_DOT_NET_SLASH_SECEVENT_SLASH_RISC_SLASH_DELIVERY_MINUS_METHOD_SLASH_PUSH = 'https://schemas.openid.net/secevent/risc/delivery-method/push'
    HTTPS_COLON_SLASH_SLASH_SCHEMAS_DOT_OPENID_DOT_NET_SLASH_SECEVENT_SLASH_RISC_SLASH_DELIVERY_MINUS_METHOD_SLASH_POLL = 'https://schemas.openid.net/secevent/risc/delivery-method/poll'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of DeliveryMethodEnum from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.6.4
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.api.policies_api import PoliciesApi


class TestPoliciesApi(unittest.TestCase):
    """PoliciesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = PoliciesApi()

    def tearDown(self) -> None:
        pass

    def test_policies_all_cache_clear_create(self) -> None:
        """Test case for policies_all_cache_clear_create

        """
        pass

    def test_policies_all_cache_info_retrieve(self) -> None:
        """Test case for policies_all_cache_info_retrieve

        """
        pass

    def test_policies_all_destroy(self) -> None:
        """Test case for policies_all_destroy

        """
        pass

    def test_policies_all_list(self) -> None:
        """Test case for policies_all_list

        """
        pass

    def test_policies_all_retrieve(self) -> None:
        """Test case for policies_all_retrieve

        """
        pass

    def test_policies_all_test_create(self) -> None:
        """Test case for policies_all_test_create

        """
        pass

    def test_policies_all_types_list(self) -> None:
        """Test case for policies_all_types_list

        """
        pass

    def test_policies_all_used_by_list(self) -> None:
        """Test case for policies_all_used_by_list

        """
        pass

    def test_policies_bindings_create(self) -> None:
        """Test case for policies_bindings_create

        """
        pass

    def test_policies_bindings_destroy(self) -> None:
        """Test case for policies_bindings_destroy

        """
        pass

    def test_policies_bindings_list(self) -> None:
        """Test case for policies_bindings_list

        """
        pass

    def test_policies_bindings_partial_update(self) -> None:
        """Test case for policies_bindings_partial_update

        """
        pass

    def test_policies_bindings_retrieve(self) -> None:
        """Test case for policies_bindings_retrieve

        """
        pass

    def test_policies_bindings_update(self) -> None:
        """Test case for policies_bindings_update

        """
        pass

    def test_policies_bindings_used_by_list(self) -> None:
        """Test case for policies_bindings_used_by_list

        """
        pass

    def test_policies_dummy_create(self) -> None:
        """Test case for policies_dummy_create

        """
        pass

    def test_policies_dummy_destroy(self) -> None:
        """Test case for policies_dummy_destroy

        """
        pass

    def test_policies_dummy_list(self) -> None:
        """Test case for policies_dummy_list

        """
        pass

    def test_policies_dummy_partial_update(self) -> None:
        """Test case for policies_dummy_partial_update

        """
        pass

    def test_policies_dummy_retrieve(self) -> None:
        """Test case for policies_dummy_retrieve

        """
        pass

    def test_policies_dummy_update(self) -> None:
        """Test case for policies_dummy_update

        """
        pass

    def test_policies_dummy_used_by_list(self) -> None:
        """Test case for policies_dummy_used_by_list

        """
        pass

    def test_policies_event_matcher_create(self) -> None:
        """Test case for policies_event_matcher_create

        """
        pass

    def test_policies_event_matcher_destroy(self) -> None:
        """Test case for policies_event_matcher_destroy

        """
        pass

    def test_policies_event_matcher_list(self) -> None:
        """Test case for policies_event_matcher_list

        """
        pass

    def test_policies_event_matcher_partial_update(self) -> None:
        """Test case for policies_event_matcher_partial_update

        """
        pass

    def test_policies_event_matcher_retrieve(self) -> None:
        """Test case for policies_event_matcher_retrieve

        """
        pass

    def test_policies_event_matcher_update(self) -> None:
        """Test case for policies_event_matcher_update

        """
        pass

    def test_policies_event_matcher_used_by_list(self) -> None:
        """Test case for policies_event_matcher_used_by_list

        """
        pass

    def test_policies_expression_create(self) -> None:
        """Test case for policies_expression_create

        """
        pass

    def test_policies_expression_destroy(self) -> None:
        """Test case for policies_expression_destroy

        """
        pass

    def test_policies_expression_list(self) -> None:
        """Test case for policies_expression_list

        """
        pass

    def test_policies_expression_partial_update(self) -> None:
        """Test case for policies_expression_partial_update

        """
        pass

    def test_policies_expression_retrieve(self) -> None:
        """Test case for policies_expression_retrieve

        """
        pass

    def test_policies_expression_update(self) -> None:
        """Test case for policies_expression_update

        """
        pass

    def test_policies_expression_used_by_list(self) -> None:
        """Test case for policies_expression_used_by_list

        """
        pass

    def test_policies_geoip_create(self) -> None:
        """Test case for policies_geoip_create

        """
        pass

    def test_policies_geoip_destroy(self) -> None:
        """Test case for policies_geoip_destroy

        """
        pass

    def test_policies_geoip_iso3166_list(self) -> None:
        """Test case for policies_geoip_iso3166_list

        """
        pass

    def test_policies_geoip_list(self) -> None:
        """Test case for policies_geoip_list

        """
        pass

    def test_policies_geoip_partial_update(self) -> None:
        """Test case for policies_geoip_partial_update

        """
        pass

    def test_policies_geoip_retrieve(self) -> None:
        """Test case for policies_geoip_retrieve

        """
        pass

    def test_policies_geoip_update(self) -> None:
        """Test case for policies_geoip_update

        """
        pass

    def test_policies_geoip_used_by_list(self) -> None:
        """Test case for policies_geoip_used_by_list

        """
        pass

    def test_policies_password_create(self) -> None:
        """Test case for policies_password_create

        """
        pass

    def test_policies_password_destroy(self) -> None:
        """Test case for policies_password_destroy

        """
        pass

    def test_policies_password_expiry_create(self) -> None:
        """Test case for policies_password_expiry_create

        """
        pass

    def test_policies_password_expiry_destroy(self) -> None:
        """Test case for policies_password_expiry_destroy

        """
        pass

    def test_policies_password_expiry_list(self) -> None:
        """Test case for policies_password_expiry_list

        """
        pass

    def test_policies_password_expiry_partial_update(self) -> None:
        """Test case for policies_password_expiry_partial_update

        """
        pass

    def test_policies_password_expiry_retrieve(self) -> None:
        """Test case for policies_password_expiry_retrieve

        """
        pass

    def test_policies_password_expiry_update(self) -> None:
        """Test case for policies_password_expiry_update

        """
        pass

    def test_policies_password_expiry_used_by_list(self) -> None:
        """Test case for policies_password_expiry_used_by_list

        """
        pass

    def test_policies_password_list(self) -> None:
        """Test case for policies_password_list

        """
        pass

    def test_policies_password_partial_update(self) -> None:
        """Test case for policies_password_partial_update

        """
        pass

    def test_policies_password_retrieve(self) -> None:
        """Test case for policies_password_retrieve

        """
        pass

    def test_policies_password_update(self) -> None:
        """Test case for policies_password_update

        """
        pass

    def test_policies_password_used_by_list(self) -> None:
        """Test case for policies_password_used_by_list

        """
        pass

    def test_policies_reputation_create(self) -> None:
        """Test case for policies_reputation_create

        """
        pass

    def test_policies_reputation_destroy(self) -> None:
        """Test case for policies_reputation_destroy

        """
        pass

    def test_policies_reputation_list(self) -> None:
        """Test case for policies_reputation_list

        """
        pass

    def test_policies_reputation_partial_update(self) -> None:
        """Test case for policies_reputation_partial_update

        """
        pass

    def test_policies_reputation_retrieve(self) -> None:
        """Test case for policies_reputation_retrieve

        """
        pass

    def test_policies_reputation_scores_destroy(self) -> None:
        """Test case for policies_reputation_scores_destroy

        """
        pass

    def test_policies_reputation_scores_list(self) -> None:
        """Test case for policies_reputation_scores_list

        """
        pass

    def test_policies_reputation_scores_retrieve(self) -> None:
        """Test case for policies_reputation_scores_retrieve

        """
        pass

    def test_policies_reputation_scores_used_by_list(self) -> None:
        """Test case for policies_reputation_scores_used_by_list

        """
        pass

    def test_policies_reputation_update(self) -> None:
        """Test case for policies_reputation_update

        """
        pass

    def test_policies_reputation_used_by_list(self) -> None:
        """Test case for policies_reputation_used_by_list

        """
        pass

    def test_policies_unique_password_create(self) -> None:
        """Test case for policies_unique_password_create

        """
        pass

    def test_policies_unique_password_destroy(self) -> None:
        """Test case for policies_unique_password_destroy

        """
        pass

    def test_policies_unique_password_list(self) -> None:
        """Test case for policies_unique_password_list

        """
        pass

    def test_policies_unique_password_partial_update(self) -> None:
        """Test case for policies_unique_password_partial_update

        """
        pass

    def test_policies_unique_password_retrieve(self) -> None:
        """Test case for policies_unique_password_retrieve

        """
        pass

    def test_policies_unique_password_update(self) -> None:
        """Test case for policies_unique_password_update

        """
        pass

    def test_policies_unique_password_used_by_list(self) -> None:
        """Test case for policies_unique_password_used_by_list

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.6.4
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.api.events_api import EventsApi


class TestEventsApi(unittest.TestCase):
    """EventsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = EventsApi()

    def tearDown(self) -> None:
        pass

    def test_events_events_actions_list(self) -> None:
        """Test case for events_events_actions_list

        """
        pass

    def test_events_events_create(self) -> None:
        """Test case for events_events_create

        """
        pass

    def test_events_events_destroy(self) -> None:
        """Test case for events_events_destroy

        """
        pass

    def test_events_events_list(self) -> None:
        """Test case for events_events_list

        """
        pass

    def test_events_events_partial_update(self) -> None:
        """Test case for events_events_partial_update

        """
        pass

    def test_events_events_retrieve(self) -> None:
        """Test case for events_events_retrieve

        """
        pass

    def test_events_events_top_per_user_list(self) -> None:
        """Test case for events_events_top_per_user_list

        """
        pass

    def test_events_events_update(self) -> None:
        """Test case for events_events_update

        """
        pass

    def test_events_events_volume_list(self) -> None:
        """Test case for events_events_volume_list

        """
        pass

    def test_events_notifications_destroy(self) -> None:
        """Test case for events_notifications_destroy

        """
        pass

    def test_events_notifications_list(self) -> None:
        """Test case for events_notifications_list

        """
        pass

    def test_events_notifications_mark_all_seen_create(self) -> None:
        """Test case for events_notifications_mark_all_seen_create

        """
        pass

    def test_events_notifications_partial_update(self) -> None:
        """Test case for events_notifications_partial_update

        """
        pass

    def test_events_notifications_retrieve(self) -> None:
        """Test case for events_notifications_retrieve

        """
        pass

    def test_events_notifications_update(self) -> None:
        """Test case for events_notifications_update

        """
        pass

    def test_events_notifications_used_by_list(self) -> None:
        """Test case for events_notifications_used_by_list

        """
        pass

    def test_events_rules_create(self) -> None:
        """Test case for events_rules_create

        """
        pass

    def test_events_rules_destroy(self) -> None:
        """Test case for events_rules_destroy

        """
        pass

    def test_events_rules_list(self) -> None:
        """Test case for events_rules_list

        """
        pass

    def test_events_rules_partial_update(self) -> None:
        """Test case for events_rules_partial_update

        """
        pass

    def test_events_rules_retrieve(self) -> None:
        """Test case for events_rules_retrieve

        """
        pass

    def test_events_rules_update(self) -> None:
        """Test case for events_rules_update

        """
        pass

    def test_events_rules_used_by_list(self) -> None:
        """Test case for events_rules_used_by_list

        """
        pass

    def test_events_system_tasks_list(self) -> None:
        """Test case for events_system_tasks_list

        """
        pass

    def test_events_system_tasks_retrieve(self) -> None:
        """Test case for events_system_tasks_retrieve

        """
        pass

    def test_events_system_tasks_run_create(self) -> None:
        """Test case for events_system_tasks_run_create

        """
        pass

    def test_events_transports_create(self) -> None:
        """Test case for events_transports_create

        """
        pass

    def test_events_transports_destroy(self) -> None:
        """Test case for events_transports_destroy

        """
        pass

    def test_events_transports_list(self) -> None:
        """Test case for events_transports_list

        """
        pass

    def test_events_transports_partial_update(self) -> None:
        """Test case for events_transports_partial_update

        """
        pass

    def test_events_transports_retrieve(self) -> None:
        """Test case for events_transports_retrieve

        """
        pass

    def test_events_transports_test_create(self) -> None:
        """Test case for events_transports_test_create

        """
        pass

    def test_events_transports_update(self) -> None:
        """Test case for events_transports_update

        """
        pass

    def test_events_transports_used_by_list(self) -> None:
        """Test case for events_transports_used_by_list

        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.6.4
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.models.reputation_policy_request import ReputationPolicyRequest

class TestReputationPolicyRequest(unittest.TestCase):
    """ReputationPolicyRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ReputationPolicyRequest:
        """Test ReputationPolicyRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ReputationPolicyRequest`
        """
        model = ReputationPolicyRequest()
        if include_optional:
            return ReputationPolicyRequest(
                name = '0',
                execution_logging = True,
                check_ip = True,
                check_username = True,
                threshold = -2147483648
            )
        else:
            return ReputationPolicyRequest(
                name = '0',
        )
        """

    def testReputationPolicyRequest(self):
        """Test ReputationPolicyRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.6.4
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.models.system_info_runtime import SystemInfoRuntime

class TestSystemInfoRuntime(unittest.TestCase):
    """SystemInfoRuntime unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SystemInfoRuntime:
        """Test SystemInfoRuntime
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SystemInfoRuntime`
        """
        model = SystemInfoRuntime()
        if include_optional:
            return SystemInfoRuntime(
                python_version = '',
                environment = '',
                architecture = '',
                platform = '',
                uname = '',
                openssl_version = '',
                openssl_fips_enabled = True,
                authentik_version = ''
            )
        else:
            return SystemInfoRuntime(
                python_version = '',
                environment = '',
                architecture = '',
                platform = '',
                uname = '',
                openssl_version = '',
                openssl_fips_enabled = True,
                authentik_version = '',
        )
        """

    def testSystemInfoRuntime(self):
        """Test SystemInfoRuntime"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.6.4
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from authentik_client.models.policy_engine_mode import PolicyEngineMode
from authentik_client.models.provider import Provider
from typing import Optional, Set
from typing_extensions import Self

class Application(BaseModel):
    """
    Application Serializer
    """ # noqa: E501
    pk: StrictStr
    name: StrictStr = Field(description="Application's display Name.")
    slug: Annotated[str, Field(strict=True, max_length=50)] = Field(description="Internal application name, used in URLs.")
    provider: Optional[StrictInt] = None
    provider_obj: Provider
    backchannel_providers: Optional[List[StrictInt]] = None
    backchannel_providers_obj: List[Provider]
    launch_url: Optional[StrictStr] = Field(description="Allow formatting of launch URL")
    open_in_new_tab: Optional[StrictBool] = Field(default=None, description="Open launch URL in a new browser tab or window.")
    meta_launch_url: Optional[StrictStr] = None
    meta_icon: Optional[StrictStr] = Field(description="Get the URL to the App Icon image. If the name is /static or starts with http it is returned as-is")
    meta_description: Optional[StrictStr] = None
    meta_publisher: Optional[StrictStr] = None
    policy_engine_mode: Optional[PolicyEngineMode] = None
    group: Optional[StrictStr] = None
    __properties: ClassVar[List[str]] = ["pk", "name", "slug", "provider", "provider_obj", "backchannel_providers", "backchannel_providers_obj", "launch_url", "open_in_new_tab", "meta_launch_url", "meta_icon", "meta_description", "meta_publisher", "policy_engine_mode", "group"]

    @field_validator('slug')
    def slug_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if not re.match(r"^[-a-zA-Z0-9_]+$", value):
            raise ValueError(r"must validate the regular expression /^[-a-zA-Z0-9_]+$/")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Application from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        """
        excluded_fields: Set[str] = set([
            "pk",
            "provider_obj",
            "backchannel_providers_obj",
            "launch_url",
            "meta_icon",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of provider_obj
        if self.provider_obj:
            _dict['provider_obj'] = self.provider_obj.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in backchannel_providers_obj (list)
        _items = []
        if self.backchannel_providers_obj:
            for _item_backchannel_providers_obj in self.backchannel_providers_obj:
                if _item_backchannel_providers_obj:
                    _items.append(_item_backchannel_providers_obj.to_dict())
            _dict['backchannel_providers_obj'] = _items
        # set to None if provider (nullable) is None
        # and model_fields_set contains the field
        if self.provider is None and "provider" in self.model_fields_set:
            _dict['provider'] = None

        # set to None if launch_url (nullable) is None
        # and model_fields_set contains the field
        if self.launch_url is None and "launch_url" in self.model_fields_set:
            _dict['launch_url'] = None

        # set to None if meta_icon (nullable) is None
        # and model_fields_set contains the field
        if self.meta_icon is None and "meta_icon" in self.model_fields_set:
            _dict['meta_icon'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Application from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "pk": obj.get("pk"),
            "name": obj.get("name"),
            "slug": obj.get("slug"),
            "provider": obj.get("provider"),
            "provider_obj": Provider.from_dict(obj["provider_obj"]) if obj.get("provider_obj") is not None else None,
            "backchannel_providers": obj.get("backchannel_providers"),
            "backchannel_providers_obj": [Provider.from_dict(_item) for _item in obj["backchannel_providers_obj"]] if obj.get("backchannel_providers_obj") is not None else None,
            "launch_url": obj.get("launch_url"),
            "open_in_new_tab": obj.get("open_in_new_tab"),
            "meta_launch_url": obj.get("meta_launch_url"),
            "meta_icon": obj.get("meta_icon"),
            "meta_description": obj.get("meta_description"),
            "meta_publisher": obj.get("meta_publisher"),
            "policy_engine_mode": obj.get("policy_engine_mode"),
            "group": obj.get("group")
        })
        return _obj





# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.6.4
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.models.transaction_application_request import TransactionApplicationRequest

class TestTransactionApplicationRequest(unittest.TestCase):
    """TransactionApplicationRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> TransactionApplicationRequest:
        """Test TransactionApplicationRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `TransactionApplicationRequest`
        """
        model = TransactionApplicationRequest()
        if include_optional:
            return TransactionApplicationRequest(
                app = authentik_client.models.application_request.ApplicationRequest(
                    name = '0', 
                    slug = 'z0', 
                    provider = 56, 
                    backchannel_providers = [
                        56
                        ], 
                    open_in_new_tab = True, 
                    meta_launch_url = '', 
                    meta_description = '', 
                    meta_publisher = '', 
                    policy_engine_mode = 'all', 
                    group = '', ),
                provider_model = 'authentik_providers_google_workspace.googleworkspaceprovider',
                provider = None,
                policy_bindings = [
                    authentik_client.models.transaction_policy_binding_request.TransactionPolicyBindingRequest(
                        policy = '', 
                        group = '', 
                        user = 56, 
                        negate = True, 
                        enabled = True, 
                        order = -2147483648, 
                        timeout = 0, 
                        failure_result = True, )
                    ]
            )
        else:
            return TransactionApplicationRequest(
                app = authentik_client.models.application_request.ApplicationRequest(
                    name = '0', 
                    slug = 'z0', 
                    provider = 56, 
                    backchannel_providers = [
                        56
                        ], 
                    open_in_new_tab = True, 
                    meta_launch_url = '', 
                    meta_description = '', 
                    meta_publisher = '', 
                    policy_engine_mode = 'all', 
                    group = '', ),
                provider_model = 'authentik_providers_google_workspace.googleworkspaceprovider',
                provider = None,
        )
        """

    def testTransactionApplicationRequest(self):
        """Test TransactionApplicationRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.6.4
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.models.patched_kerberos_source_request import PatchedKerberosSourceRequest

class TestPatchedKerberosSourceRequest(unittest.TestCase):
    """PatchedKerberosSourceRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PatchedKerberosSourceRequest:
        """Test PatchedKerberosSourceRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PatchedKerberosSourceRequest`
        """
        model = PatchedKerberosSourceRequest()
        if include_optional:
            return PatchedKerberosSourceRequest(
                name = '0',
                slug = 'z0',
                enabled = True,
                authentication_flow = '',
                enrollment_flow = '',
                user_property_mappings = [
                    ''
                    ],
                group_property_mappings = [
                    ''
                    ],
                policy_engine_mode = 'all',
                user_matching_mode = 'identifier',
                user_path_template = '0',
                group_matching_mode = 'identifier',
                realm = '0',
                krb5_conf = '',
                kadmin_type = 'MIT',
                sync_users = True,
                sync_users_password = True,
                sync_principal = '',
                sync_password = '',
                sync_keytab = '',
                sync_ccache = '',
                spnego_server_name = '',
                spnego_keytab = '',
                spnego_ccache = '',
                password_login_update_internal_password = True
            )
        else:
            return PatchedKerberosSourceRequest(
        )
        """

    def testPatchedKerberosSourceRequest(self):
        """Test PatchedKerberosSourceRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.6.4
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.models.user_consent import UserConsent

class TestUserConsent(unittest.TestCase):
    """UserConsent unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> UserConsent:
        """Test UserConsent
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `UserConsent`
        """
        model = UserConsent()
        if include_optional:
            return UserConsent(
                pk = 56,
                expires = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                expiring = True,
                user = authentik_client.models.user.User(
                    pk = 56, 
                    username = '', 
                    name = '', 
                    is_active = True, 
                    last_login = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    date_joined = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    is_superuser = True, 
                    groups = [
                        ''
                        ], 
                    groups_obj = [
                        authentik_client.models.user_group.UserGroup(
                            pk = '', 
                            num_pk = 56, 
                            name = '', 
                            is_superuser = True, 
                            parent = '', 
                            parent_name = '', 
                            attributes = {
                                'key' : null
                                }, )
                        ], 
                    email = '', 
                    avatar = '', 
                    attributes = {
                        'key' : null
                        }, 
                    uid = '', 
                    path = '', 
                    type = 'internal', 
                    uuid = '', 
                    password_change_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ),
                application = authentik_client.models.application.Application(
                    pk = '', 
                    name = '', 
                    slug = 'z', 
                    provider = 56, 
                    provider_obj = null, 
                    backchannel_providers = [
                        56
                        ], 
                    backchannel_providers_obj = [
                        authentik_client.models.provider.Provider(
                            pk = 56, 
                            name = '', 
                            authentication_flow = '', 
                            authorization_flow = '', 
                            invalidation_flow = '', 
                            property_mappings = [
                                ''
                                ], 
                            component = '', 
                            assigned_application_slug = '', 
                            assigned_application_name = '', 
                            assigned_backchannel_application_slug = '', 
                            assigned_backchannel_application_name = '', 
                            verbose_name = '', 
                            verbose_name_plural = '', 
                            meta_model_name = '', )
                        ], 
                    launch_url = '', 
                    open_in_new_tab = True, 
                    meta_launch_url = '', 
                    meta_icon = '', 
                    meta_description = '', 
                    meta_publisher = '', 
                    policy_engine_mode = 'all', 
                    group = '', ),
                permissions = ''
            )
        else:
            return UserConsent(
                pk = 56,
                user = authentik_client.models.user.User(
                    pk = 56, 
                    username = '', 
                    name = '', 
                    is_active = True, 
                    last_login = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    date_joined = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    is_superuser = True, 
                    groups = [
                        ''
                        ], 
                    groups_obj = [
                        authentik_client.models.user_group.UserGroup(
                            pk = '', 
                            num_pk = 56, 
                            name = '', 
                            is_superuser = True, 
                            parent = '', 
                            parent_name = '', 
                            attributes = {
                                'key' : null
                                }, )
                        ], 
                    email = '', 
                    avatar = '', 
                    attributes = {
                        'key' : null
                        }, 
                    uid = '', 
                    path = '', 
                    type = 'internal', 
                    uuid = '', 
                    password_change_date = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ),
                application = authentik_client.models.application.Application(
                    pk = '', 
                    name = '', 
                    slug = 'z', 
                    provider = 56, 
                    provider_obj = null, 
                    backchannel_providers = [
                        56
                        ], 
                    backchannel_providers_obj = [
                        authentik_client.models.provider.Provider(
                            pk = 56, 
                            name = '', 
                            authentication_flow = '', 
                            authorization_flow = '', 
                            invalidation_flow = '', 
                            property_mappings = [
                                ''
                                ], 
                            component = '', 
                            assigned_application_slug = '', 
                            assigned_application_name = '', 
                            assigned_backchannel_application_slug = '', 
                            assigned_backchannel_application_name = '', 
                            verbose_name = '', 
                            verbose_name_plural = '', 
                            meta_model_name = '', )
                        ], 
                    launch_url = '', 
                    open_in_new_tab = True, 
                    meta_launch_url = '', 
                    meta_icon = '', 
                    meta_description = '', 
                    meta_publisher = '', 
                    policy_engine_mode = 'all', 
                    group = '', ),
        )
        """

    def testUserConsent(self):
        """Test UserConsent"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.6.4
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.models.flow_inspection import FlowInspection

class TestFlowInspection(unittest.TestCase):
    """FlowInspection unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> FlowInspection:
        """Test FlowInspection
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `FlowInspection`
        """
        model = FlowInspection()
        if include_optional:
            return FlowInspection(
                plans = [
                    authentik_client.models.flow_inspector_plan.FlowInspectorPlan(
                        current_stage = null, 
                        next_planned_stage = null, 
                        plan_context = {
                            'key' : null
                            }, 
                        session_id = '', )
                    ],
                current_plan = authentik_client.models.flow_inspector_plan.FlowInspectorPlan(
                    current_stage = null, 
                    next_planned_stage = null, 
                    plan_context = {
                        'key' : null
                        }, 
                    session_id = '', ),
                is_completed = True
            )
        else:
            return FlowInspection(
                plans = [
                    authentik_client.models.flow_inspector_plan.FlowInspectorPlan(
                        current_stage = null, 
                        next_planned_stage = null, 
                        plan_context = {
                            'key' : null
                            }, 
                        session_id = '', )
                    ],
                is_completed = True,
        )
        """

    def testFlowInspection(self):
        """Test FlowInspection"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.6.4
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.models.user_self import UserSelf

class TestUserSelf(unittest.TestCase):
    """UserSelf unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> UserSelf:
        """Test UserSelf
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `UserSelf`
        """
        model = UserSelf()
        if include_optional:
            return UserSelf(
                pk = 56,
                username = 'A',
                name = '',
                is_active = True,
                is_superuser = True,
                groups = [
                    authentik_client.models.user_self_groups.UserSelfGroups(
                        name = '', 
                        pk = '', )
                    ],
                email = '',
                avatar = '',
                uid = '',
                settings = {
                    'key' : null
                    },
                type = 'internal',
                system_permissions = [
                    ''
                    ]
            )
        else:
            return UserSelf(
                pk = 56,
                username = 'A',
                name = '',
                is_active = True,
                is_superuser = True,
                groups = [
                    authentik_client.models.user_self_groups.UserSelfGroups(
                        name = '', 
                        pk = '', )
                    ],
                avatar = '',
                uid = '',
                settings = {
                    'key' : null
                    },
                system_permissions = [
                    ''
                    ],
        )
        """

    def testUserSelf(self):
        """Test UserSelf"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.6.4
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from authentik_client.models.footer_link import FooterLink
from authentik_client.models.ui_theme_enum import UiThemeEnum
from typing import Optional, Set
from typing_extensions import Self

class CurrentBrand(BaseModel):
    """
    Partial brand information for styling
    """ # noqa: E501
    matched_domain: StrictStr
    branding_title: StrictStr
    branding_logo: StrictStr
    branding_favicon: StrictStr
    branding_custom_css: StrictStr
    ui_footer_links: List[FooterLink]
    ui_theme: UiThemeEnum
    flow_authentication: Optional[StrictStr] = None
    flow_invalidation: Optional[StrictStr] = None
    flow_recovery: Optional[StrictStr] = None
    flow_unenrollment: Optional[StrictStr] = None
    flow_user_settings: Optional[StrictStr] = None
    flow_device_code: Optional[StrictStr] = None
    default_locale: StrictStr
    __properties: ClassVar[List[str]] = ["matched_domain", "branding_title", "branding_logo", "branding_favicon", "branding_custom_css", "ui_footer_links", "ui_theme", "flow_authentication", "flow_invalidation", "flow_recovery", "flow_unenrollment", "flow_user_settings", "flow_device_code", "default_locale"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CurrentBrand from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        """
        excluded_fields: Set[str] = set([
            "ui_footer_links",
            "ui_theme",
            "default_locale",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in ui_footer_links (list)
        _items = []
        if self.ui_footer_links:
            for _item_ui_footer_links in self.ui_footer_links:
                if _item_ui_footer_links:
                    _items.append(_item_ui_footer_links.to_dict())
            _dict['ui_footer_links'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CurrentBrand from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "matched_domain": obj.get("matched_domain"),
            "branding_title": obj.get("branding_title"),
            "branding_logo": obj.get("branding_logo"),
            "branding_favicon": obj.get("branding_favicon"),
            "branding_custom_css": obj.get("branding_custom_css"),
            "ui_footer_links": [FooterLink.from_dict(_item) for _item in obj["ui_footer_links"]] if obj.get("ui_footer_links") is not None else None,
            "ui_theme": obj.get("ui_theme"),
            "flow_authentication": obj.get("flow_authentication"),
            "flow_invalidation": obj.get("flow_invalidation"),
            "flow_recovery": obj.get("flow_recovery"),
            "flow_unenrollment": obj.get("flow_unenrollment"),
            "flow_user_settings": obj.get("flow_user_settings"),
            "flow_device_code": obj.get("flow_device_code"),
            "default_locale": obj.get("default_locale")
        })
        return _obj





# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.6.4
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.models.system_info import SystemInfo

class TestSystemInfo(unittest.TestCase):
    """SystemInfo unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SystemInfo:
        """Test SystemInfo
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SystemInfo`
        """
        model = SystemInfo()
        if include_optional:
            return SystemInfo(
                http_headers = {
                    'key' : ''
                    },
                http_host = '',
                http_is_secure = True,
                runtime = authentik_client.models.system_info_runtime.SystemInfo_runtime(
                    python_version = '', 
                    environment = '', 
                    architecture = '', 
                    platform = '', 
                    uname = '', 
                    openssl_version = '', 
                    openssl_fips_enabled = True, 
                    authentik_version = '', ),
                brand = '',
                server_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                embedded_outpost_disabled = True,
                embedded_outpost_host = ''
            )
        else:
            return SystemInfo(
                http_headers = {
                    'key' : ''
                    },
                http_host = '',
                http_is_secure = True,
                runtime = authentik_client.models.system_info_runtime.SystemInfo_runtime(
                    python_version = '', 
                    environment = '', 
                    architecture = '', 
                    platform = '', 
                    uname = '', 
                    openssl_version = '', 
                    openssl_fips_enabled = True, 
                    authentik_version = '', ),
                brand = '',
                server_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                embedded_outpost_disabled = True,
                embedded_outpost_host = '',
        )
        """

    def testSystemInfo(self):
        """Test SystemInfo"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.6.4
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.models.google_workspace_provider_group import GoogleWorkspaceProviderGroup

class TestGoogleWorkspaceProviderGroup(unittest.TestCase):
    """GoogleWorkspaceProviderGroup unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> GoogleWorkspaceProviderGroup:
        """Test GoogleWorkspaceProviderGroup
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `GoogleWorkspaceProviderGroup`
        """
        model = GoogleWorkspaceProviderGroup()
        if include_optional:
            return GoogleWorkspaceProviderGroup(
                id = '',
                google_id = '',
                group = '',
                group_obj = authentik_client.models.user_group.UserGroup(
                    pk = '', 
                    num_pk = 56, 
                    name = '', 
                    is_superuser = True, 
                    parent = '', 
                    parent_name = '', 
                    attributes = {
                        'key' : null
                        }, ),
                provider = 56,
                attributes = {
                    'key' : null
                    }
            )
        else:
            return GoogleWorkspaceProviderGroup(
                id = '',
                google_id = '',
                group = '',
                group_obj = authentik_client.models.user_group.UserGroup(
                    pk = '', 
                    num_pk = 56, 
                    name = '', 
                    is_superuser = True, 
                    parent = '', 
                    parent_name = '', 
                    attributes = {
                        'key' : null
                        }, ),
                provider = 56,
                attributes = {
                    'key' : null
                    },
        )
        """

    def testGoogleWorkspaceProviderGroup(self):
        """Test GoogleWorkspaceProviderGroup"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.6.4
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.models.license_summary import LicenseSummary

class TestLicenseSummary(unittest.TestCase):
    """LicenseSummary unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> LicenseSummary:
        """Test LicenseSummary
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `LicenseSummary`
        """
        model = LicenseSummary()
        if include_optional:
            return LicenseSummary(
                internal_users = 56,
                external_users = 56,
                status = 'unlicensed',
                latest_valid = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                license_flags = [
                    'trial'
                    ]
            )
        else:
            return LicenseSummary(
                internal_users = 56,
                external_users = 56,
                status = 'unlicensed',
                latest_valid = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                license_flags = [
                    'trial'
                    ],
        )
        """

    def testLicenseSummary(self):
        """Test LicenseSummary"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
